{% extends "base.html" %}

{% block title %}403 - Permission denied{% endblock %}

{% block content %}
<div class="container">
    <div class="row">
        <div class="span12">
            <div class="hero-unit">
                <h1>403</h1>
                <h2>Permission Denied</h2>
            </div>
        </div>
    </div>
</div>
{% endblock %}

