<!DOCTYPE html>
<html>
    <head>
        <title>{% block title %}Guardian example{% endblock %}</title>
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <!-- Bootstrap -->
        <link href="{{ STATIC_URL }}css/bootstrap.min.css" rel="stylesheet" media="screen">
        <style>
            .container {
                margin-top: 60px;
            }
        </style>
    </head>
    <body>
        {% block navbar %}
        <div class="navbar navbar-inverse navbar-fixed-top">
            <div class="navbar-inner">
                <div class="container-fluid">
                    <button type="button" class="btn btn-navbar" data-toggle="collapse" data-target=".nav-collapse">
                        <span class="icon-bar"></span>
                        <span class="icon-bar"></span>
                        <span class="icon-bar"></span>
                    </button>
                    <a class="brand" href="#">Guardian example project v{{ version }}</a>
                    <div class="nav-collapse collapse">
                        <ul class="nav">
                            <li class="active"><a href="{% url "posts_post_list" %}">Posts</a></li>
                            <li><a href="https://github.com/lukaszb/django-guardian" target="_repo">Repository</a></li>
                            <li><a href="https://github.com/lukaszb/django-guardian/issues" target="_issues">Issue tracker</a></li>
                            <li><a href="https://django-guardian.readthedocs.org/en/latest/" target="_docs">Documentation</a></li>
                        </ul>
                        <p class="navbar-text pull-right">
                        {% if user.is_authenticated %}
                        Logged in as {{ user }}. <a href="{% url "logout" %}" class="navbar-link">Logout</a>
                        {% else %}
                        Not authenticated. Please use <a href="/admin/" class="navbar-link">admin</a> to login.
                        {% endif %}
                        </p>
                    </div><!--/.nav-collapse -->
                </div>
            </div>
        </div>
        {% endblock %}
        <div class="container">
            {% block content %}
            <div class="row">
                <div class="span12">
                    <h1>Hello, world!</h1>
                </div>
            </div>
            {% endblock %}
        </div>
        <script src="http://code.jquery.com/jquery.js"></script>
        <script src="{{ STATIC_URL }}js/bootstrap.min.js"></script>
    </body>
</html>


