{% extends "admin/change_form.html" %}
{% load i18n %}

{% block extrahead %}{{ block.super }}
{{ form.media }}
{% endblock %}

{% block breadcrumbs %}{% if not is_popup %}
<ul>
    <li><a href="../../../../../../">{% trans "Home" %}</a></li>
    <li><a href="../../../../../">{% trans app_label|capfirst|escape %}</a></li>
    <li>{% if has_change_permission %}<a href="../../../../">{{ opts.verbose_name_plural|capfirst }}</a>{% else %}{{ opts.verbose_name_plural|capfirst }}{% endif %}</li>
    <li>{% if has_change_permission %}<a href="../../../">{{ original|truncatewords:"18" }}</a>{% else %}{{ original|truncatewords:"18" }}{% endif %}</li>
    <li>{% if has_change_permission %}<a href="../../">{% trans "Object permissions" %}</a>{% else %}{% trans "Object permissions" %}{% endif %}</li>
    <li>{% trans "Manage group" %}: {{ group_obj|truncatewords:"18" }}</li>
</ul>
{% endif %}{% endblock %}


{% block content %}
<form action="." method="post">
    {% csrf_token %}
    <div>
    <fieldset class="grp-module">
        <h2 class="grp-collapse-handler">{% trans "Object permissions" %}</h2>
        <div class="grp-row grp-cells-1 object">
            <div class="l-2c-fluid l-d-4">
                <div class="c-1"><label for="object" class="required">{% trans "Object" %}</label></div>
                <div class="c-2"><div id="object" class="grp-readonly">{{ object }}</div></div>
            </div>
        </div>
        <div class="grp-row grp-cells-1 user">
            <div class="l-2c-fluid l-d-4">
                <div class="c-1"><label for="group" class="required">{% trans "Group" %}</label></div>
                <div class="c-2"><div id="group" class="grp-readonly">{{ group_obj }}</div></div>
            </div>
        </div>
        {% for field in form %}
            {% include "admin/guardian/contrib/grappelli/field.html" %}
        {% endfor %}
        <div class="grp-row grp-cells-1">
            <div class="l-2c-fluid l-d-4">
                <div class="c-1">&nbsp;</div>
                <div class="c-2">
                    <input id="submit" type="submit" value="{% trans "Save" %}"/>
                </div>
            </div>
        </div>
    </fieldset>
    </div>
</form>
{% endblock %}
