{% extends "base.html" %}

{% block title %}404 - Page does not exist{% endblock %}

{% block content %}
<div class="container">
    <div class="row">
        <div class="span12">
            <div class="hero-unit">
                <h1>404</h1>
                <h2>Page does not exist</h2>
            </div>
        </div>
    </div>
</div>
{% endblock %}


